==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/languages/messages/MessagesZa.php <==
<?php
/** Zhuang ((Cuengh))
 *
 * @addtogroup Language
 *
 * @author Hakka
 */

$fallback = 'zh-cn';

$messages = array(
# Dates
'sunday'        => 'Swnggeiz Yaet',
'monday'        => 'Swnggeiz Wtx',
'tuesday'       => 'Swnggeiz Yeih',
'wednesday'     => 'Swnggeiz Sam',
'thursday'      => 'Swnggeiz Seiq',
'friday'        => 'Swnggeiz Haj',
'saturday'      => 'Swnggeiz Lokj',
'january'       => 'Nin Wtj',
'february'      => 'Nin Yeih',
'march'         => 'Nin Sam',
'april'         => 'Nin Seiq',
'may_long'      => 'Nin Haj',
'june'          => 'Nin Loekj',
'july'          => 'Nin Caet',
'august'        => 'Nin Betq',
'september'     => 'Nin Gouj',
'october'       => 'Nin Cwbx',
'november'      => 'Nin Cwbx Wtj',
'december'      => 'Nin Cwbx Yeih',
'may-gen'       => 'Nin Haj',
'september-gen' => 'Nin Gouj',
'sep'           => 'Nin Gouj',

'cancel'         => 'Fwtqfex',
'qbspecialpages' => 'Doenghmae daegxsei',
'mytalk'         => 'Gaeq gou gangj',
'navigation'     => 'Dazzaeuh',

'help'             => 'Caeuq',
'search'           => 'Cwmh',
'searchbutton'     => 'Cwmh',
'searcharticle'    => 'Bei',
'history_short'    => 'Doenghmatq',
'permalink'        => 'Gaeq-lamh kaemdaengz',
'protect'          => 'Hahdiuz',
'talk'             => 'Kwng',
'toolbox'          => 'Loengx hong',
'jumptonavigation' => 'Dazzaeuh',
'jumptosearch'     => 'Cwmh',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'edithelp' => 'Caeuq mungz san-zonz',
'mainpage' => 'Mae meh',

'youhavenewmessages' => 'Mungz meiz $1（$2）。',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Faenzueng',
'nstab-user' => 'Mae bouxdeiz',

# General errors
'viewsource' => 'Liuq lagh mae-nej',

# Login and logout pages
'yourname'    => 'Ciu bouxdeiz:',
'notloggedin' => 'Maengx laezhaej',
'username'    => 'Ciu bouxdeiz:',

# Edit pages
'summary'            => 'Saegmangj',
'minoredit'          => 'Di-nej gaij noix',
'watchthis'          => 'Demq mae-nej',
'savearticle'        => 'Zonzdiuz mae-nej',
'showpreview'        => 'Okqhaej piu-ngoengx',
'showdiff'           => 'Okqhaej gaeqgaei',
'whitelistedittitle' => 'Laezdiuz haeuj aiq naej san-zonz',

# Search results
'powersearch' => 'Cwmh',

# Preferences page
'mypreferences'     => 'Doenghgaeq gou hae',
'prefsnologin'      => 'Maengx laezhaej',
'searchresultshead' => 'Cwmh',

# Recent changes
'recentchanges' => 'Gaeqgaij suijnej',

# Upload
'uploadnologin'     => 'Maengx laezhaej',
'filedesc'          => 'Saegmangj',
'fileuploadsummary' => 'Saegmangj:',
'watchthisupload'   => 'Demq mae-nej',

# Image list
'ilsubmit' => 'Cwmh',

# Random page
'randompage' => 'Mae zaihzex',

# Miscellaneous special pages
'specialpages'      => 'Doenghmae daegxsei',
'newpages-username' => 'Ciu bouxdeiz:',
'move'              => 'Caen',
'movethispage'      => 'Caen mae nej',

# Special:Log
'log-search-submit' => 'Bei',

# Watchlist
'watchlist'     => 'Gaeq gou demq',
'mywatchlist'   => 'Gaeq gou demq',
'watchnologin'  => 'Maengx laezhaej',
'watch'         => 'Demq',
'watchthispage' => 'Demq mae-nej',

# Restrictions (nouns)
'restriction-move' => 'Caen',

# Contributions
'contributions' => 'Gaeq bouxdeiz haej',
'mycontris'     => 'Gaeq gou haej',

'sp-contributions-submit' => 'Cwmh',

# What links here
'whatlinkshere' => 'Maelaez lamh haenznej',

# Block/unblock
'ipblocklist-submit' => 'Cwmh',

# Move page
'movepage'    => 'Caen doengh mae',
'movearticle' => 'Caen doengh mae:',
'movenologin' => 'Maengx laezhaej',
'move-watch'  => 'Demq mae-nej',
'movepagebtn' => 'Caen doengh mae',
'movedto'     => 'Caen bei',
'1movedto2'   => '[[$1]] caen bei [[$2]]',
'movereason'  => 'Haujgaemj',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Doenghgaeq gou hae',
'tooltip-p-logo'         => 'Mae meh',

# Multipage image navigation
'imgmultigo' => 'Bei！',

# Table pager
'table_pager_limit_submit' => 'Bei',

);

==> mediawiki_1.15.1.orig.tar.gz: mediawiki-1.15.1/languages/messages/MessagesZa.php <==
<?php
/** Zhuang (Vahcuengh)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Biŋhai
 * @author Hakka
 */

$fallback = 'zh-hans';

$messages = array(
# Dates
'sunday'        => 'Swnggeiz Yaet',
'monday'        => 'Swnggeiz Wtx',
'tuesday'       => 'Swnggeiz Yeih',
'wednesday'     => 'Swnggeiz Sam',
'thursday'      => 'Swnggeiz Seiq',
'friday'        => 'Swnggeiz Haj',
'saturday'      => 'Swnggeiz Lokj',
'january'       => 'Nin Wtj',
'february'      => 'Nin Yeih',
'march'         => 'Nin Sam',
'april'         => 'Nin Seiq',
'may_long'      => 'Nin Haj',
'june'          => 'Nin Loekj',
'july'          => 'Nin Caet',
'august'        => 'Nin Betq',
'september'     => 'Nin Gouj',
'october'       => 'Nin Cwbx',
'november'      => 'Nin Cwbx Wtj',
'december'      => 'Nin Cwbx Yeih',
'may-gen'       => 'Nin Haj',
'september-gen' => 'Nin Gouj',
'sep'           => 'Nin Gouj',

'about'          => 'Gvendaengz',
'article'        => 'Banjbienj',
'cancel'         => 'Fwtqfex',
'qbfind'         => 'Ra',
'qbedit'         => 'Gaij',
'qbspecialpages' => 'Doenghmae daegxsei',
'mytalk'         => 'Gaeq gou gangj',
'navigation'     => 'Dazzaeuh',

'help'             => 'Caeuq',
'search'           => 'Cwmh',
'searchbutton'     => 'Cwmh',
'go'               => 'Bae',
'searcharticle'    => 'Bae',
'history'          => 'Lizsij',
'history_short'    => 'Doenghmatq',
'permalink'        => 'Gaeq-lamh kaemdaengz',
'edit'             => 'gaij',
'delete'           => 'Duz',
'protect'          => 'Hahdiuz',
'newpage'          => 'Bienj moq',
'talkpagelinktext' => 'Daujlun',
'talk'             => 'Kwng',
'toolbox'          => 'Loengx hong',
'jumptonavigation' => 'Dazzaeuh',
'jumptosearch'     => 'Cwmh',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'edithelp'             => 'Caeuq mungz san-zonz',
'mainpage'             => 'Mbaw meh',
'mainpage-description' => 'Mae meh',

'youhavenewmessages' => 'Mungz meiz $1（$2）。',
'editsection'        => 'gaij',
'editold'            => 'gaij',
'editlink'           => 'gaij',
'editsectionhint'    => 'Gaij duenh:$1',
'hidetoc'            => 'cangz',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Faenzueng',
'nstab-user' => 'Mae bouxdeiz',

# General errors
'viewsource' => 'Liuq lagh mae-nej',

# Login and logout pages
'yourname'    => 'Ciu bouxdeiz:',
'login'       => 'Dwnghluz',
'notloggedin' => 'Maengx laezhaej',
'username'    => 'Ciu bouxdeiz:',

# Edit pages
'summary'            => 'Saegmangj:',
'minoredit'          => 'Di-nej gaij noix',
'watchthis'          => 'Demq mae-nej',
'savearticle'        => 'Zonzdiuz mae-nej',
'showpreview'        => 'Okqhaej piu-ngoengx',
'showdiff'           => 'Okqhaej gaeqgaei',
'whitelistedittitle' => 'Laezdiuz haeuj aiq naej san-zonz',

# Diffs
'editundo' => 'siu',

# Search results
'search-interwiki-more' => '（more）',
'powersearch'           => 'Cwmh',

# Preferences page
'mypreferences'     => 'Doenghgaeq gou hae',
'prefsnologin'      => 'Maengx laezhaej',
'searchresultshead' => 'Cwmh',

# Recent changes
'recentchanges' => 'Gaeqgaij suijnej',
'diff'          => 'Faenbied',

# Upload
'uploadnologin'     => 'Maengx laezhaej',
'filedesc'          => 'Saegmangj',
'fileuploadsummary' => 'Saegmangj:',
'watchthisupload'   => 'Demq mae-nej',

# Special:ListFiles
'listfiles_user' => 'Bouxyungh',

# File description page
'filehist-user' => 'Bouxsawjyungh',

# Random page
'randompage' => 'Mae zaihzex',

# Miscellaneous special pages
'newpages-username' => 'Ciu bouxdeiz:',
'move'              => 'Daen',
'movethispage'      => 'Caen mae nej',

# Book sources
'booksources-go' => 'Bae',

# Special:Log
'log' => 'Ngoenzceiq',

# Special:AllPages
'allpagessubmit' => 'Bae',

# Watchlist
'watchlist'     => 'Gaeq gou demq',
'mywatchlist'   => 'Gaeq gou demq',
'watchnologin'  => 'Maengx laezhaej',
'watch'         => 'Demq',
'watchthispage' => 'Demq mae-nej',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Bawxndu……',
'unwatching' => 'Souma bawxndu……',

# Protect
'prot_1movedto2' => '[[$1]] caen bei [[$2]]',

# Restrictions (nouns)
'restriction-move' => 'Caen',

# Namespace form on various pages
'blanknamespace' => '（Cujyau）',

# Contributions
'contributions' => 'Gaeq bouxdeiz haej',
'mycontris'     => 'Gaeq gou haej',

'sp-contributions-submit' => 'Cwmh',

# What links here
'whatlinkshere' => 'Maelaez lamh haenznej',

# Block/unblock
'ipblocklist-submit' => 'Cwmh',

# Move page
'move-page-legend' => 'Caen doengh mae',
'movearticle'      => 'Caen doengh mae:',
'movenologin'      => 'Maengx laezhaej',
'move-watch'       => 'Demq mae-nej',
'movepagebtn'      => 'Caen doengh mae',
'movedto'          => 'Caen bei',
'1movedto2'        => '[[$1]] caen bei [[$2]]',
'movereason'       => 'Haujgaemj',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Doenghgaeq gou hae',
'tooltip-p-logo'         => 'Mae meh',

# Special:NewFiles
'ilsubmit' => 'Cwmh',

# Multipage image navigation
'imgmultigo' => 'Bei！',

# Table pager
'table_pager_limit_submit' => 'Bei',

# Special:SpecialPages
'specialpages' => 'Doenghmae daegxsei',

# Special:Tags
'tags-edit' => 'gaij',

);
